@@ -5,6 +5,7 @@ from typing import List, Text
 
 import click
 import randomname
+from rich.console import Console
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import NAME_GENERATOR_CONFIG
@@ -26,6 +27,8 @@ from neuralspace.nlu.apis import (
 from neuralspace.nlu.constants import SUPPORTED_LANGUAGES, TRAINING_PROGRESS
 from neuralspace.utils import print_logo, setup_logger
 
+console = Console()
+
 
 @click.group(name="nlu")
 def nlu():
