@@ -118,22 +118,7 @@ def get_list_chunks(items: List[Any], chunk_size: int):
         yield items[chunk : chunk + chunk_size]  # noqa : E203
 
 
-def print_logo_and_description():
-    console.print(f"[bold]{get_logo()}[/bold]", style="#c47900")
-    console.print(
-        "[bold magenta]Website: [/bold magenta][link]https://neuralspace.ai[/link]"
-    )
-    console.print(
-        "[bold magenta]Docs: [/bold magenta][link]https://docs.neuralspace.ai[/link]"
-    )
-    console.print(
-        "[bold magenta]Platform Login: [/bold magenta][link]https://platform.neuralspace.ai[/link]"
-    )
-    console.print("[bold magenta]Commands: [/bold magenta]")
-    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
-    table.add_column("Name", style="#c47900")
-    table.add_column("Command", style="#c47900")
-    table.add_column("Description")
+def add_apps_to_table(table: Table) -> Table:
     table.add_row(
         "[bold]nlu[/bold]",
         "neuralspace [bold red]nlu[/bold red]",
@@ -155,6 +140,46 @@ def print_logo_and_description():
         "addresses, account numbers to very domain specific terms like names of chemicals, medicines, etc. "
         "Essentially any valuable information that can be extracted from text.",
     )
+    return table
+
+
+def add_heading_to_description_table(table: Table) -> Table:
+    table.add_column("Name", style="#c47900")
+    table.add_column("Command", style="#c47900")
+    table.add_column("Description")
+    return table
+
+
+def print_logo_and_description():
+    console.print(f"[bold]{get_logo()}[/bold]", style="#c47900")
+    console.print(
+        "[bold magenta]Website: [/bold magenta][link]https://neuralspace.ai[/link]"
+    )
+    console.print(
+        "[bold magenta]Docs: [/bold magenta][link]https://docs.neuralspace.ai[/link]"
+    )
+    console.print(
+        "[bold magenta]Platform Login: [/bold magenta][link]https://platform.neuralspace.ai[/link]"
+    )
+    console.print("[bold magenta]Commands: [/bold magenta]")
+    table = Table(show_header=True, header_style="bold #c47900", show_lines=True)
+    table = add_heading_to_description_table(table)
+    table.add_row(
+        "[bold]Login[/bold]",
+        "neuralspace [bold red]login[/bold red]",
+        "Login to the our platform and save credentials locally",
+    )
+    table.add_row(
+        "[bold]List Apps[/bold]",
+        "neuralspace [bold red]list-apps[/bold red]",
+        "List all the available apps in our platform and their respective codes",
+    )
+    table.add_row(
+        "[bold]Install App[/bold]",
+        "neuralspace [bold red]install-app[/bold red]",
+        "Installs the specific app on your account",
+    )
+    table = add_apps_to_table(table)
     console.print(table)
 
 
